package Translation;

# This file is part of the pnopaste program
# Copyright (C) 2008-2010 Patrick Matthäi <pmatthaei@debian.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

use warnings;
use strict;


our %Strings = (
	1	=> 'Temps d\'expiration invalide.',
	2	=> 'Votre Nom d\'hôte est blacklisté.',
	3	=> 'Vous utilisez un ou plusieurs mots incorrect dans le champ de code.',
	4	=> 'Le code du langage fourni n\'est pas présent.',
	5	=> 'L\'utilisateur n\'a pas laissé de description.',
	6	=> 'Ici',
	7	=> 'Temps de calcul:',
	8	=> 'sec',
	9	=> 'Votre nom:',
	10	=> 'Expire dans:',
	11	=> 'Coloration syntaxique:',
	12	=> 'Description:',
	13	=> 'Code:',
	14	=> 'Insérer:',
	15	=> 'Bonjour, Votre code a été ajouté avec succès.',
	16	=> 'Vous pouvez, maintenant, acceder à votre paste sur',
	17	=> 'Vous pouvez également obtenir un lien vers une ligne spécifique, par exemple:',
	18	=> 'où',
	19	=> 'est le numéro de ligne.',
	20	=> 'Si vous souhaitez télécharger le code en plain/text, aller sur',
	21	=> 'Si vous souhaitez ajouter une nouvelle entrée,',
	22	=> 'cliquez ici',
	23	=> 'Telecharger:',
	24	=> 'Nouveau:',
	25	=> 'Pas de past pour:',
	26	=> 'Expire le:',
	27	=> 'De:',
	28	=> 'Langage:'
);

1;
